JsDoc Reference - links.Filter

Class Index | File Index

## Classes

- _global_
- links.Filter
- links.Graph3d
- links.Graph3d.Camera
- links.Slider

# Class links.Filter

Filter
Defined in: graph3d.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| links.Filter(data, column, graph)

Method Summary
Method Attributes | Method Name and Description
--- | ---
| getColumn() Return the columnIndex of the filter
| getLabel() Return the label
| getLoadedProgress() Return the loaded progress
| getSelectedValue() Return the currently selected value.
| getValue(index) Retrieve one value of the filter
| getValues() Retrieve all values of the filter
| isLoaded() Return the label
| loadInBackground(index) Load all filtered rows in the background one by one Start this method without providing an index!
| selectValue(index) Add a value to the list with available values for this filter No double entries will be created.
| setOnLoadCallback(callback) Set a callback function when the filter is fully loaded.

Class Detail
links.Filter(data, column, graph)

Parameters:
{google.visualization.DataTable} data
  The google data table
{number} column
  The index of the column to be filtered
{links.Graph} graph
  The graph

Method Detail
{number} getColumn()
Return the columnIndex of the filter

Returns:
  {number} columnIndex

{string} getLabel()
Return the label

Returns:
  {string} label

{number} getLoadedProgress()
Return the loaded progress

Returns:
  {number} percentage between 0 and 100

{*} getSelectedValue()
Return the currently selected value. Returns undefined if there is no selection

Returns:
  {*} value

{*} getValue(index)
Retrieve one value of the filter

Parameters:
{number} index

Returns:
  {*} value

{Array} getValues()
Retrieve all values of the filter

Returns:
  {Array} values

{string} isLoaded()
Return the label

Returns:
  {string} label

loadInBackground(index)
Load all filtered rows in the background one by one Start this method without providing an index!

Parameters:
index

selectValue(index)
Add a value to the list with available values for this filter No double entries will be created.

Parameters:
{number} index

setOnLoadCallback(callback)
Set a callback function when the filter is fully loaded.

Parameters:
callback

Documentation generated by JsDoc Toolkit 2.3.2 on Wed Oct 24 2012 10:03:15 GMT+0200 (CEST)